function X = pcentroid(dp)
%PCENTROID Centroid for belief distribution over probability measures.
%   X = PCENTROID(dp) returns the centroid for the belief distribution
%   over the probability measures of the given decision problem.
%
%   See also UCENTROID.
  
  X = [];
  for n = 1:length(dp.A)
    for m = 1:length(dp.A(n).C)
      X = [X; pmean(dp.A(n).C(m))];
    end
  end
  
  
function x = pmean(c)
%PMEAN Mean for local belief distribution over probability measure.
%   x = PMEAN(c) returns the mean for the belief distribution over the
%   probability measure of the given consequence.
%
%   If the belief distribution does not contain a variable, then it is
%   interpreted as a constant specifying the mean of of the belief
%   distribution.
  
  if isempty(findstr(c.pdist, 'x'))
    x = str2num(c.pdist);
  else
    x = quad8(inline(strcat('x.*(', c.pdist, ')')), 0, 1);
  end